@@ -15,7 +15,7 @@ from appzoo.utils import get_module_path
 
 def ocr_result_image(result, input_image, output_image='output_image.png'):
     # https://raw.githubusercontent.com/PaddlePaddle/PaddleOCR/develop/doc/simfang.ttf
-    image = Image.open(input_image)  # .convert('RGB')
+    image = Image.open(input_image).convert('RGB')
     boxes = [line[0] for line in result]
     txts = [line[1][0] for line in result]
     scores = [line[1][1] for line in result]
